searchData={"items":[{"type":"module","title":"Websocket","doc":"","ref":"Websocket.html"},{"type":"module","title":"Websocket.ClientJS","doc":"","ref":"Websocket.ClientJS.html"},{"type":"function","title":"Websocket.ClientJS.client_js/0","doc":"","ref":"Websocket.ClientJS.html#client_js/0"},{"type":"module","title":"Websocket.Handler","doc":"Websocket.Handler provides a macro-based approach to handle WebSocket connections in a Plug-based application.\nThis module also serves the JavaScript WebSocket client code at the `/ws/client.js` endpoint.","ref":"Websocket.Handler.html"},{"type":"module","title":"Usage - Websocket.Handler","doc":"To use Websocket.Handler, you need to include it in your application’s router module and define event handlers using the provided macros.\n\n```elixir\ndefmodule MyWebsocketRouter do\n  use Websocket.Handler\n\n  on(:connect) do\n    IO.puts(\"Client connected\")\n  end\n\n  on(:disconnect) do\n    IO.puts(\"Client disconnected\")\n  end\n\n  on(:json) do\n    IO.puts(\"Received JSON: #{inspect(conn.json)}\")\n  end\n\n  on(:file) do\n    # Save the file to disk or process it\n    IO.puts(\"Received file\")\n  end\n\n  on(:message) do\n    IO.puts(\"Received message: #{conn.message}\")\n  end\nend\n```","ref":"Websocket.Handler.html#module-usage"},{"type":"module","title":"Routes - Websocket.Handler","doc":"- **`get \"/client.js\"`**: Serves the JavaScript WebSocket client at the `/ws/client.js` endpoint.\n- **`forward \"/ws\"`**: Reserved for WebSocket connections. Forwards WebSocket requests to the module where event handlers are defined.","ref":"Websocket.Handler.html#module-routes"},{"type":"module","title":"Macros - Websocket.Handler","doc":"- **`on(event, do: block)`**: Defines a callback for a specific WebSocket event. Supported events include:\n  - `:connect`: Triggered when a client connects.\n  - `:disconnect`: Triggered when a client disconnects.\n  - `:json`: Triggered when a JSON message is received.\n  - `:file`: Triggered when binary data (file) is received.\n  - `:message`: Triggered when a plain text message is received.","ref":"Websocket.Handler.html#module-macros"},{"type":"function","title":"Websocket.Handler.call/2","doc":"","ref":"Websocket.Handler.html#call/2"},{"type":"function","title":"Websocket.Handler.handle_event/2","doc":"","ref":"Websocket.Handler.html#handle_event/2"},{"type":"function","title":"Websocket.Handler.init/1","doc":"","ref":"Websocket.Handler.html#init/1"},{"type":"function","title":"Websocket.Handler.websocket_handle/3","doc":"","ref":"Websocket.Handler.html#websocket_handle/3"},{"type":"function","title":"Websocket.Handler.websocket_init/3","doc":"","ref":"Websocket.Handler.html#websocket_init/3"},{"type":"function","title":"Websocket.Handler.websocket_terminate/3","doc":"","ref":"Websocket.Handler.html#websocket_terminate/3"},{"type":"extras","title":"Websocket Handler","doc":"# Websocket Handler\n\nWebsocket Handler is a macro-based approach to handling WebSocket connections in a Plug-based Elixir application. It also serves a JavaScript WebSocket client at a specific endpoint, making it easy to integrate WebSocket communication into web applications.\n\n## `Websocket.Handler`\n\nModule allows you to define WebSocket routes and event handlers using a simple, macro-based syntax. It automatically serves the JavaScript WebSocket client at the `/ws/client.js` endpoint.","ref":"readme.html"},{"type":"extras","title":"Usage - Websocket Handler","doc":"To use `Websocket.Handler`, you need to include it in your application’s router module and define event handlers using the provided macros.\n\n```elixir\ndefmodule MyWebsocketRouter do\n  use Websocket.Handler\n\n  on(:connect) do\n    IO.puts(\"Client connected\")\n  end\n\n  on(:disconnect) do\n    IO.puts(\"Client disconnected\")\n  end\n\n  on(:json) do\n    IO.puts(\"Received JSON: #{inspect(conn.json)}\")\n  end\n\n  on(:file) do\n    # Save the file to disk or process it\n    IO.puts(\"Received file\")\n  end\n\n  on(:message) do\n    # Message is just plain text.\n    IO.puts(\"Received message: #{conn.message}\")\n  end\nend\n```\n\nThen in your Plug router, simply forward your websocket route to your handler.\n\n```elixir\ndefmodule MyAppRouter do\n  use Plug.Router\n\n  plug :match\n  plug :dispatch\n\n  forward \"/ws\", to: MyWebsocketRouter\n\n  match _ do\n    send_resp(conn, 404, \"Not Found\")\n  end\nend\n```\n\n#### Events\n\n  - `:connect`: Triggered when a client connects.\n  - `:disconnect`: Triggered when a client disconnects.\n  - `:json`: Triggered when a JSON message is received.\n  - `:file`: Triggered when binary data (file) is received.\n  - `:message`: Triggered when a plain text message is received.\n\n> `ws/client.js` is generated to handle websocket connection and callbacks for on: json, text/message and file. Just include it.","ref":"readme.html#usage"},{"type":"extras","title":"Example Usage - Websocket Handler","doc":"Here’s how you can include and use the WebSocket client in your HTML files:\n\n```html\n<!DOCTYPE html>\n \n \n     \n     \n     WebSocket Client \n \n \n      \n     \n        client.onJson((data) => {\n            console.log('Received JSON:', data);\n        });\n\n        client.onFile((data) => {\n            console.log('Received file data');\n            const fileUrl = URL.createObjectURL(data);\n            const link = document.createElement('a');\n            link.href = fileUrl;\n            link.download = 'downloaded_file';\n            link.click();\n            URL.revokeObjectURL(fileUrl);\n        });\n\n        client.onMessage((message) => {\n            console.log('Received message:', message);\n        });\n\n        client.onConnect(() => {\n            console.log('Connected to WebSocket server');\n        });\n\n        client.onDisconnect(() => {\n            console.log('Disconnected from WebSocket server');\n        });\n\n        // Sending different types of data using the new syntax\n        client.send(json({ hello: \"world\" }));\n        client.send(\"some text\");\n        const fileBlob = new Blob([\"This is a file content\"], { type: 'text/plain' });\n        client.send(file(fileBlob));\n     \n \n \n```","ref":"readme.html#example-usage"},{"type":"extras","title":"License - Websocket Handler","doc":"This project is licensed under the MIT License.","ref":"readme.html#license"}],"content_type":"text/markdown","producer":{"name":"ex_doc","version":[48,46,51,52,46,50]}}